@@ -5,10 +5,11 @@ import matplotlib.pyplot as plt
 #####
 
 
-###################
+
+        
 ####XMCD######
 def XMCD(pdat,mdat,ene,det,mon,
-         log=False,xmin=None,xmax=None,xsize=10000, norm='edge_jump'):
+         log=False,xmin=None,xmax=None,xsize=10000, norm='edge_jump',eshift=0):
     '''
     xray magnetic circular dichroism function
 
@@ -27,6 +28,7 @@ def XMCD(pdat,mdat,ene,det,mon,
                   ! be careful: low point density can lead to ValueErrors due to 
                   ! rounding numbers
         norm    = choose normalization from ['white_line', 'edge_jump', 'pre_edge','None']
+        eshift  = shift in energy, added to pdat values, default 0
 
     Returns
     --------
@@ -38,6 +40,7 @@ def XMCD(pdat,mdat,ene,det,mon,
 
     no notes 
     '''
+    from scipy import interpolate
     t2pdat = pdat
     t2mdat = mdat
     #photon energies: 
@@ -53,14 +56,13 @@ def XMCD(pdat,mdat,ene,det,mon,
         mmax.append(np.max(t2mdat[n][ene]))
     
     #used energy range:
-    #choose whole range if not specified: 
     if xmin == None:
         xmin = np.max(pmin+mmin)
     if xmax == None:
         xmax = np.min(pmax+mmax)
     
     # energy interpolation range:
-    xx = np.linspace(xmin+0.01,xmax-0.01,xsize) 
+    xx = np.linspace(xmin+0.1,xmax-0.1,xsize) 
     t3pdat=[] # alles interpolierte
     for n in range(len(t2pdat)):
         v1  = np.array(t2pdat[n][ene])
@@ -73,14 +75,20 @@ def XMCD(pdat,mdat,ene,det,mon,
                 v2  = v21/v22
         if mon == False:
             v2 = np.array(t2pdat[n][det])
-        t3pdat.append(interpolate.interp1d(v1,v2)(xx)) 
+        try:
+            t3pdat.append(interpolate.interp1d(v1,v2)(xx+float(eshift)/1000)) 
+        except:
+            raise ValueError('eshift to large for interpolation range? max Eshift ca. 100meV')
     t3mdat=[]
     for n in range(len(t2mdat)):
         v1  = np.array(t2mdat[n][ene])
         if mon != False:
             v21 = np.array(t2mdat[n][det])
             v22 = np.array(t2mdat[n][mon])
-            v2  = v21/v22
+            if log == True:
+                v2  = np.log(v22/v21)
+            else:
+                v2  = v21/v22
         if mon == False:
             v2 = np.array(t2mdat[n][det])
         t3mdat.append(interpolate.interp1d(v1,v2)(xx))
@@ -116,7 +124,6 @@ def XMCD(pdat,mdat,ene,det,mon,
     pxas   = t5pdat - linbkg
     mxas   = t5mdat - linbkg
     
-
     ### normalization:
 
     norm_opt = ['white_line', 'edge_jump', 'pre_edge','None',None]
@@ -125,7 +132,7 @@ def XMCD(pdat,mdat,ene,det,mon,
     
     try:
         if norm == 'white_line':
-         norm_factor = float(np.max(xas))
+             norm_factor = float(np.max(xas))
         
         elif norm == 'edge_jump':
             last_values  = int(xsize*0.05)
@@ -155,6 +162,8 @@ def XMCD(pdat,mdat,ene,det,mon,
 # mHYST
 #
 ### new in 0.1.10, developed for many (mHYST) loops in one file:
+### added log option in 0.1.13
+
 class mHYST:
     '''
     Arguments
@@ -167,6 +176,7 @@ class mHYST:
         ene_cut = energy cutoff, choose somewhere between both 
                   measured energies
         ratio   = either divide higher/lower or lower/higher energy
+        log     = neg. logarithm for tranmission experiments, default False
     
     Returns
     --------
@@ -180,8 +190,8 @@ class mHYST:
     
     '''
     
-    def __init__(self, df, ene, det, mon, ene_cut, ratio='higher/lower'):
-        
+    def __init__(self, df, ene, det, mon, ene_cut, ratio='higher/lower',log=False):
+        import pandas as pd
         if not isinstance(df, pd.DataFrame):
             raise ValueError('df is not a pd.DataFrame')
         t1      = df
@@ -200,6 +210,9 @@ class mHYST:
             if mon == False: 
                 t2['normlzd'] = t2[det]
                 t3['normlzd'] = t3[det]
+            elif log == True:
+                t2['normlzd'] = -np.log(t2[det]/t2[mon])
+                t3['normlzd'] = -np.log(t3[det]/t3[mon])
             else:
                 t2['normlzd'] = t2[det]/t2[mon]
                 t3['normlzd'] = t3[det]/t3[mon]
@@ -256,6 +269,7 @@ class mHYST:
         for n in av_list:
             toaverage.append(self.t2['divided'][n*self.len_per_loop:(n+1)*self.len_per_loop])
         averaged = np.mean(toaverage,axis=0)
+        self.std      = np.std(toaverage,axis=0) 
         field = self.t2['Magnet Field'][:self.len_per_loop]
         
         if return_data == False:
